==> jaysonic-3.3.1.tgz: package/lib/client/http.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

var JsonRpcClientFactory = require(".");

var HttpClientProtocol = require("./protocol/http");
/**
 * Creates instance of HttpClientFactory
 *
 * @extends JsonRpcClientFactory
 */


var HttpClientFactory = /*#__PURE__*/function (_JsonRpcClientFactory) {
  _inherits(HttpClientFactory, _JsonRpcClientFactory);

  var _super = _createSuper(HttpClientFactory);

  /**
   * Additional parameters and properties ontop of those inherited from [JsonRpcClientFactory]{@link JsonRpcClientFactory}
   *
   * @param {Object} options Connection options for the factory class
   * @param {string} [options.encoding="utf-8"] Encoding to be used for the request
   * @param {string} [options.method="POST"] Type of request to make
   * @param {object} [options.headers={"Content-Type": "application/json", Accept: "application/json"}] Request headers
   * @param {string}  [options.path="/"] URL path to make request to
   * @property {object} headers Same as `options.headers`
   * @property {string} encoding Same as `options.encoding`
   * @property {'http'|'https'} scheme Scheme to make connection with
   */
  function HttpClientFactory(options) {
    var _this;

    _classCallCheck(this, HttpClientFactory);

    _this = _super.call(this, options);

    if (!(_assertThisInitialized(_this) instanceof HttpClientFactory)) {
      return _possibleConstructorReturn(_this, new HttpClientFactory(options));
    }

    var defaults = {
      encoding: "utf-8",
      method: "POST",
      path: "/",
      scheme: "http"
    }; // the Content-Length header will be calculated on a per request basis

    _this.options = _objectSpread(_objectSpread(_objectSpread({}, defaults), _this.options || {}), {}, {
      headers: _objectSpread({
        "Content-Type": "application/json",
        Accept: "application/json"
      }, _this.options.headers)
    });
    _this.headers = _this.options.headers;
    _this.encoding = _this.options.encoding;
    _this.scheme = _this.options.scheme;
    _this.pcolInstance = new HttpClientProtocol(_assertThisInitialized(_this), _this.options.version, _this.options.delimiter, _this.options.scheme);
    return _this;
  }

  return HttpClientFactory;
}(JsonRpcClientFactory);

module.exports = HttpClientFactory;

==> jaysonic-3.5.1.tgz: package/lib/client/http.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

var JsonRpcClientFactory = require(".");

var HttpClientProtocol = require("./protocol/http");
/**
 * Creates instance of HttpClientFactory
 *
 * @extends JsonRpcClientFactory
 */


var HttpClientFactory = /*#__PURE__*/function (_JsonRpcClientFactory) {
  _inherits(HttpClientFactory, _JsonRpcClientFactory);

  var _super = _createSuper(HttpClientFactory);

  /**
   * Additional parameters and properties ontop of those inherited from [JsonRpcClientFactory]{@link JsonRpcClientFactory}
   *
   * @param {Object} options Connection options for the factory class
   * @param {string} [options.encoding="utf-8"] Encoding to be used for the request
   * @param {string} [options.method="POST"] Type of request to make
   * @param {object} [options.headers={"Content-Type": "application/json", Accept: "application/json"}] Request headers
   * @param {string}  [options.path="/"] URL path to make request to
   * @property {object} headers Same as `options.headers`
   * @property {string} encoding Same as `options.encoding`
   * @property {'http'|'https'} scheme Scheme to make connection with
   */
  function HttpClientFactory(options) {
    var _this;

    _classCallCheck(this, HttpClientFactory);

    _this = _super.call(this, options);

    if (!(_assertThisInitialized(_this) instanceof HttpClientFactory)) {
      return _possibleConstructorReturn(_this, new HttpClientFactory(options));
    }

    var defaults = {
      encoding: "utf-8",
      method: "POST",
      path: "/",
      scheme: "http"
    }; // the Content-Length header will be calculated on a per request basis

    _this.options = _objectSpread(_objectSpread(_objectSpread({}, defaults), _this.options || {}), {}, {
      headers: _objectSpread({
        "Content-Type": "application/json",
        Accept: "application/json"
      }, _this.options.headers)
    });
    _this.protocol = HttpClientProtocol;
    _this.headers = _this.options.headers;
    _this.encoding = _this.options.encoding;
    _this.scheme = _this.options.scheme;
    _this.pcolInstance = new _this.protocol(_assertThisInitialized(_this), _this.options.version, _this.options.delimiter, _this.options.scheme);
    return _this;
  }

  return HttpClientFactory;
}(JsonRpcClientFactory);

module.exports = HttpClientFactory;
